%% info
% This self-contained script generates Fig. 15 of our paper,
% Kevin C. Zhou, Ruobing Qian, Al-Hafeez Dhalla, Sina Farsiu, Joseph A.
% Izatt, "Unified k-space theory of optical coherence tomography", to
% appear in Advances in Optics and Photonics.
%% run simulation
z = -50:.1:50;  % um
lambda = .8;  % center wavelength in um
k0 = 2*pi/lambda;  % center wavenumber
PSF = @(z0, s, k) exp(-(z-z0).^2/2/s^2).*exp(2*1i*k*(z-z0));
s = 10;  % PSF width
n = 1500;  % controls discretization
dzs = linspace(-20, 20, n);  % scatterer spacings in um

% for the three panels of the figure:
incoherent = zeros(n, length(z));
coherent = zeros(n, length(z));
ocrt = zeros(n, length(z));
for i = 1:length(dzs)  % get result for each scatterer spacing
    dz = dzs(i);
    psf_incoherent = abs(PSF(-dz, s, k0)).^2+abs(PSF(dz, s, k0)).^2;
    psf_coherent = abs(PSF(-dz, s, k0)+PSF(dz, s, k0)).^2;
    psf_ocrt = psf_incoherent + 2*exp(-(dz^2+z.^2)/s^2).*besselj(0, 4*dz*k0);
    
    incoherent(i, :) = psf_incoherent;
    coherent(i, :) = psf_coherent;
    ocrt(i, :) = psf_ocrt;
end

% now plot results:
figure('units', 'inches', 'position', [4 0.4271 5.7500 9.9375])

subaxis(1,3,1, 'sh', .01, 'sv', .01, 'margin', .05, 'marginleft', .1, 'marginbottom', .05, 'margintop', .02, 'padding',0)
imagesc(z/lambda, dzs/lambda, incoherent)
caxis([0, 4])
ylabel('$d_z/\lambda_0$', 'interpreter', 'latex', 'fontsize', 15)
xlabel('$z/\lambda_0$', 'interpreter', 'latex', 'fontsize', 15)
set(gca, 'fontsize', 12)
title('(a) Incoherent', 'fontweight', 'normal')

subaxis(1,3,2)
imagesc(z/lambda, dzs/lambda, coherent)
caxis([0, 4])
set(gca, 'ytick', [])
xlabel('$z/\lambda_0$', 'interpreter', 'latex', 'fontsize', 15)
set(gca, 'fontsize', 12)
title('(b) Coherent', 'fontweight', 'normal')

subaxis(1,3,3)
imagesc(z/lambda, dzs/lambda, ocrt)
caxis([0, 4])
set(gca, 'ytick', [])
xlabel('$z/\lambda_0$', 'interpreter', 'latex', 'fontsize', 15)
set(gca, 'fontsize', 12)
title('(c) Angle-compounded', 'fontweight', 'normal')

colormap jet