%% info
% This self-contained script generates Fig. 16 of our paper,
% Kevin C. Zhou, Ruobing Qian, Al-Hafeez Dhalla, Sina Farsiu, Joseph A.
% Izatt, "Unified k-space theory of optical coherence tomography", to
% appear in Advances in Optics and Photonics.
%%
lambda = .8;  % wavelength in um
k0 = 2*pi/lambda;  % wavenumber
FWHM_list = [2, 10];  % FWHM in um
theta_max_list = [15, 30, 60]*pi/180;  % maximum angular ranges to simulate
n_angle = 200;  % number of angular discretization levels
n_dz = 1000;  % number of axial discretization levels
dz_list = linspace(0, 5, n_dz);  % sweep axial separation in um
dx = 0;  % lateral spacing between scatterers; keep this at 0, the worst case scenario

figure('units', 'inches', 'position', [4, 4, 8, 2.5])
for a=1:2  % loop over FWHM_list
    x=0;z=0; % only look at center
    sz_FWHM = FWHM_list(a);
    sx_FWHM = FWHM_list(a);
    sz = sz_FWHM/2.355;  % convert to sigma for Gaussian
    sx = sx_FWHM/2.355;
    % oriented Gaussian with fringe:
    gauss = @(th, h, k) exp(-((x-h)*cos(th)+(z-k)*sin(th)).^2/2/sx^2-...
        ((x-h)*sin(th)-(z-k)*cos(th)).^2/2/sz^2).*...
        exp(2*1i*k0*((x-h)*sin(th)-(z-k)*cos(th)));
    
    subplot(1,2, a)
    for theta_max = theta_max_list
        % sum up over multiple angles
        th_list = linspace(-theta_max, theta_max, n_angle);
        ocrt = zeros(1, n_dz);
        incoherent = zeros(1, n_dz);
        for i=1:length(dz_list)
            PSF_ocrt = zeros(1,n_angle);
            PSF_incoherent = zeros(1,n_angle);
            PSF_reference_method = zeros(1, n_angle);
            dz = dz_list(i);
            for j=1:n_angle
                th = th_list(j);
                PSF_incoherent(j) = (abs(gauss(th, -dx/2, -dz/2)).^2+abs(gauss(th, dx/2, dz/2)).^2)/2;
                PSF_ocrt(j) = abs(gauss(th, -dx/2, -dz/2)+gauss(th, dx/2, dz/2)).^2/2;
                PSF_reference_method(j) = exp(-dz^2/4*(cos(th)^2/sz^2+sin(th)^2/sx^2))*cos(2*k0*dz*cos(th));
            end
            ocrt(i) = mean(PSF_ocrt);
            incoherent(i) = mean(PSF_incoherent);
        end
        
        plot(dz_list/lambda, ocrt - incoherent, 'linewidth', 2)
        hold on

    end
    
    % plot reference curves:
    plot(dz_list/lambda, besselj(0, 2*k0*dz_list), ':', 'linewidth', 2)
    plot(dz_list/lambda, abs(gauss(th, -dz_list/(2), 0)).*abs(gauss(th, dz_list/(2), 0)), ':', 'linewidth', 2)
    
    if a==1
        legend(['15',char(176)], ['30',char(176)], ['60',char(176)], 'Bessel', 'Gaussian')
        legend boxoff
    end
    title(['(', lower(char(a + 64)), ') $\mathit{FWHM}_{xz}=', num2str(sx_FWHM), '\ \mu m$'], ...
        'fontweight', 'normal', 'interpreter', 'latex', 'fontsize', 12)
    xlabel('$d_z/\lambda_0$', 'interpreter', 'latex', 'fontsize', 12)
end
