%% info
% This script generates Visualization 1 of our paper,
% Kevin C. Zhou, Ruobing Qian, Al-Hafeez Dhalla, Sina Farsiu, Joseph A.
% Izatt, "Unified k-space theory of optical coherence tomography", to
% appear in Advances in Optics and Photonics.
%% generate video
make_video = false;  % true will save video; false will play video in matlab figure

lambda = .82;  % center wavelength in um
k0 = 2*pi/lambda;  % center wavenumber
bandwidth = 0.049452;  % um, FWHM
delta_k = pi/sqrt(log(2))*bandwidth/lambda^2;  % k bandwidth
z_res = 2*log(2)/pi*lambda^2/bandwidth;  % axial resolution
z = 50;  % position of reflector, um
k = linspace(6, 9, 1000);  % wavenumber domain
dk = k(2)-k(1);  % wavenumber spacing
gausswin = exp(-(k-k0).^2/delta_k^2);  % gaussian source spectrum / TF
dzs = 0:.01:.2*z_res;  % um; spacing between reflectors;

if make_video
    v = VideoWriter('visualization1.avi');
    v.Quality = 100;
    v.FrameRate = 5;
    open(v);
end

figure('position', [680 435 560 543])
set(gcf,'color','w');

for dz = dzs
    clf
    H_2_reflectors = (2 + cos(2*k*(z-dz)) + cos(2*k*(z+dz)))/2;
    H_1_reflector = (1 + cos(2*k*z))/2;
    
    subplot(311)
    plot(k, H_1_reflector, 'color', [.5,.5,.5])
    hold on
    plot(k, gausswin, 'k')
    plot(k, gausswin.*H_1_reflector, 'b')
    xlabel('k (rad/\mum)')
    title('(a) One-reflector spectrum', 'fontweight', 'normal')
    ylim([0, 2])
    ylabel('I(k) (a.u.)')
    legend('sample spectrum V(k)', 'transfer function', 'filtered spectrum')
    legend boxoff
    
    subplot(312)
    plot(k, H_2_reflectors, 'color', [.5,.5,.5])
    hold on
    plot(k, gausswin, 'k')
    plot(k, gausswin.*H_2_reflectors, 'r')
    xlabel('k (rad/\mum)')
    title(['(b) Two-reflector spectrum (separation = ', sprintf('%1.2f',dz*2), ...
        ' \mum, axial resolution = ', num2str(z_res), ' \mum)'] , 'fontweight', 'normal')
    ylim([0, 2])
    ylabel('I(k) (a.u.)')
    legend('sample spectrum V(k)', 'transfer function', 'filtered spectrum')
    legend boxoff
    
    subplot(313)
    A = abs(fft(H_2_reflectors.*gausswin));
    A = A(1:z*2);  % remove complex conjugate
    A_single = abs(fft(gausswin.*H_1_reflector));
    A_single = A_single(1:z*2);  % remove complex conjugate
    z_coord = linspace(0, 1/2/(dk/2/pi), length(k));
    plot(z_coord(1:z*2), A_single / 100, 'b')
    hold on
    plot(z_coord(1:z*2), A / 100, 'r')
    title('(c) A-scan (|fft\{I(k)\}|)', 'fontweight', 'normal')
    xlabel('z (\mum)')
    xlim([0, z*2])
    ylabel('A(z) (a.u.)')
    legend('1-reflector A-scan', '2-reflector A-scan')
    legend boxoff
    
    if make_video
        frame = getframe(gcf);
        writeVideo(v,frame);
    else
        pause(.05)
    end
    
end

if make_video
    close(v);
end